@@ -1,6 +1,6 @@
 """
 ********************************************************************************
-compas.datastructures
+datastructures
 ********************************************************************************
 
 .. currentmodule:: compas.datastructures
@@ -14,6 +14,15 @@ It is meant for the representation of polygonal *"surface"* meshes. A mesh can b
 connected or disconnected. A mesh can be closed or open. A mesh can be comprised
 of only vertices.
 
+Classes
+-------
+
+.. autosummary::
+    :toctree: generated/
+    :nosignatures:
+
+    Mesh
+
 Functions
 ---------
 
@@ -22,6 +31,8 @@ Functions
     :nosignatures:
 
     mesh_adjacency_matrix
+    mesh_bounding_box
+    mesh_bounding_box_xy
     mesh_connectivity_matrix
     mesh_contours_numpy
     mesh_contours_pymesh
@@ -49,22 +60,14 @@ Functions
     mesh_transform
     mesh_transformed
     mesh_unify_cycles
+
     trimesh_cotangent_laplacian_matrix
+    trimesh_gaussian_curvature
     trimesh_mean_curvature
     trimesh_remesh
     trimesh_subdivide_loop
     trimesh_vertexarea_matrix
 
-Classes
--------
-
-.. autosummary::
-    :toctree: generated/
-    :nosignatures:
-
-    Mesh
-
-
 Network
 =======
 
@@ -73,6 +76,15 @@ It is meant for the representation of networks of vertices connected by edges.
 The edges are directed. A network does not have faces. A network can be connected
 or disconnected. A network with vertices only is also a valid network.
 
+Classes
+-------
+
+.. autosummary::
+    :toctree: generated/
+    :nosignatures:
+
+    Network
+
 Functions
 ---------
 
@@ -93,16 +105,6 @@ Functions
     network_is_xy
     network_smooth_centroid
 
-Classes
--------
-
-.. autosummary::
-    :toctree: generated/
-    :nosignatures:
-
-    Network
-
-
 VolMesh
 =======
 
@@ -110,6 +112,8 @@ The volmesh is a cellular mesh. It is implemented as
 a half-plane, the three-dimensional equivalent of a half-edge. It can, for example,
 be used for the representation of subdivided/partitioned polyhedra.
 
+Classes
+-------
 
 .. autosummary::
     :toctree: generated/
@@ -117,6 +121,13 @@ be used for the representation of subdivided/partitioned polyhedra.
 
     VolMesh
 
+Functions
+---------
+
+.. autosummary::
+    :toctree: generated/
+    :nosignatures:
+
 """
 
 from __future__ import absolute_import
