@@ -15,14 +15,7 @@ from compas.geometry.transformations import matrix_from_translation
 from compas.geometry.xforms import Transformation
 
 
-__author__ = ['Romana Rust <rust@arch.ethz.ch>', ]
-__license__ = 'MIT License'
-__email__ = 'rust@arch.ethz.ch'
-
-
-__all__ = [
-    'Translation',
-]
+__all__ = ['Translation']
 
 
 class Translation(Transformation):
