@@ -1,6 +1,6 @@
 """
 ********************************************************************************
-compas.numerical
+numerical
 ********************************************************************************
 
 .. currentmodule:: compas.numerical
@@ -35,8 +35,7 @@ Solvers
     ga
     moga
     pca_numpy
-    topop2d_numpy
-    topop3d_numpy
+    topop_numpy
 
 
 Linalg
