@@ -1,10 +1,3 @@
-import os
-import inspect
-import json
-import socket
-
-import compas
-
 from compas.rpc import Server
 from compas.rpc import Service
 
@@ -13,6 +6,10 @@ class DefaultService(Service):
     pass
 
 
+# ==============================================================================
+# main
+# ==============================================================================
+
 if __name__ == '__main__':
 
     import sys
