@@ -1,6 +1,6 @@
 """
 ********************************************************************************
-compas.utilities
+utilities
 ********************************************************************************
 
 .. currentmodule:: compas.utilities
@@ -88,7 +88,6 @@ itertools
     window
     roundrobin
     powerset
-    unique_everseen
     unique_justseen
     iter_except
     first_true
